@@ -5,8 +5,8 @@
 *
 * @package language
 * @version $Id: $
-* @copyright (c) 2011 phpBB Group
-* @author 2011-07-15 - Vilius Šumskas
+* @copyright (c) 2012 phpBB Group
+* @author 2012-01-04 - Vilius Šumskas
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'	=> 'Svečių laiko juosta',
 	'SYSTEM_TIMEZONE_EXPLAIN'	=> 'Laiko juosta, kuri bus naudojama rodant laiką neprisijungusiems dalyviams (svečiams, robotams). Prisijungę dalyviai pasirenka savo laiko juostą registracijos metu ir gali ją bet kada pasikeisti savo varotojo valdymo pulte.',
 	'WARNINGS_EXPIRE'	=> 'Perspėjimo trukmė',
-	'WARNINGS_EXPIRE_EXPLAIN'	=> 'Dienų skaičius, kai perspėjimas bus automatiškai ištrintas iš vartotojo įrašo.',
+	'WARNINGS_EXPIRE_EXPLAIN'	=> 'Dienų skaičius, kai perspėjimas bus automatiškai ištrintas iš vartotojo įrašo. Jeigu norite, kad perspėjimai būtų nuolatiniai, įrašykite 0.',
 	'ACP_BOARD_FEATURES_EXPLAIN'	=> 'Čia galite įjungti/išjungti kai kurias diskusijų lentos galimybes.',
 	'ALLOW_ATTACHMENTS'	=> 'Leisti prikabinti failus',
 	'ALLOW_BIRTHDAYS'	=> 'Įjungti gimtadienius',
@@ -154,7 +154,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'	=> 'Maksimalus pranešimo nuorodų skaičius',
 	'MAX_POST_URLS_EXPLAIN'	=> 'Maksimalus URL nuorodų skaičius pranešime. Jeigu nenorite riboti nuorodų skaičiaus, įrašykite 0.',
 	'MIN_CHAR_LIMIT'	=> 'Minimalus pranešimo/žinutės simbolių skaičius',
-	'MIN_CHAR_LIMIT_EXPLAIN'	=> 'Mažiausias simbolių skaičius, kurį vartotojas turi įrašyti į pranešimą/žinutę.',
+	'MIN_CHAR_LIMIT_EXPLAIN'	=> 'Mažiausias simbolių skaičius, kurį vartotojas turi įrašyti į pranešimą/žinutę (ne mažiau nei 1).',
 	'POSTING'	=> 'Rašymas',
 	'POSTS_PER_PAGE'	=> 'Pranešimų viename puslapyje',
 	'QUOTE_DEPTH_LIMIT'	=> 'Maksimalus citatų gylis',
