@@ -5,8 +5,8 @@
 *
 * @package language
 * @version $Id: $
-* @copyright (c) 2010 phpBB Group
-* @author 2010-11-21 - Vilius Šumskas
+* @copyright (c) 2012 phpBB Group
+* @author 2012-01-04 - Vilius Šumskas
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -264,6 +264,14 @@ $lang = array_merge($lang, array(
 	'BOARD_VERSION'	=> 'Diskusijų lentos versija',
 	'DATABASE_SERVER_INFO'	=> 'Informacija apie duomenų bazės serverį',
 	'DATABASE_SIZE'	=> 'Duomenų bazės dydis',
+	'ERROR_MBSTRING_FUNC_OVERLOAD'	=> 'Funkcijų perkrovimas sukonfigūruotas neteisingai',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'	=> '<var>mbstring.func_overload</var> turi būti 0 arba 4. Dabartinę reikšmę galite matyti <samp>PHP informacijos</samp> puslapyje.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'	=> 'Kodavimo transliacija sukonfigūruota neteisingai',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> turi būti 0. Dabartinę reikšmę galite matyti <samp>PHP informacijos</samp> puslapyje.',
+	'ERROR_MBSTRING_HTTP_INPUT'	=> 'HTTP įvesties simbolių konversija sukonfigūruota neteisingai',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'	=> '<var>mbstring.http_input</var> turi būti <samp>pass</samp>. Dabartinę reikšmę galite matyti <samp>PHP informacijos</samp> puslapyje.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'	=> 'HTTP išvesties simbolių konversija sukonfigūruota neteisingai',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'	=> '<var>mbstring.http_output</var> turi būti <samp>pass</samp>. Dabartinę reikšmę galite matyti <samp>PHP informacijos</samp> puslapyje.',
 	'FILES_PER_DAY'	=> 'Prikabinti failai per dieną',
 	'FORUM_STATS'	=> 'Diskusijų statistika',
 	'GZIP_COMPRESSION'	=> 'GZip suspaudimas',
