@@ -5,8 +5,8 @@
 *
 * @package language
 * @version $Id: $
-* @copyright (c) 2011 phpBB Group
-* @author 2011-07-15 - Vilius Šumskas
+* @copyright (c) 2012 phpBB Group
+* @author 2012-01-04 - Vilius Šumskas
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -156,6 +156,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'	=> 'Rašydami naują žinutę turite nurodyti jos temą.',
 	'ENABLED'	=> 'Įjungta',
 	'ENCLOSURE'	=> 'Priedas',
+	'ENTER_USERNAME'	=> 'Įrašykite vartotojo vardą',
 	'ERR_CHANGING_DIRECTORY'	=> 'Pakeisti katalogo nepavyko.',
 	'ERR_CONNECTING_SERVER'	=> 'Prisijungti prie serverio nepavyko.',
 	'ERR_JAB_AUTH'	=> 'Nepavyko autorizuotis į Jabber serverį.',
@@ -190,6 +191,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'	=> 'Čia galite perskaityti forumo taisykles',
 	'FROM'	=> 'iš',
 	'FSOCK_DISABLED'	=> 'Operacija neįvykdyta, nes <var>fsockopen</var> funkcija yra išjungta arba nepavyko rasti nurodyto serverio.',
+	'FSOCK_TIMEOUT'	=> 'Nepavyko perskaityti tinklo srauto.',
 	'FTP_FSOCK_HOST'	=> 'FTP serveris',
 	'FTP_FSOCK_HOST_EXPLAIN'	=> 'Jūsų FTP serverio vardas.',
 	'FTP_FSOCK_PASSWORD'	=> 'FTP slaptažodis',
@@ -618,6 +620,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'	=> '<strong>%d</strong> neperskaitytos(ų) žinutės(čių)',
 	'UNREAD_POST'	=> 'Neperskaitytas pranešimas',
 	'UNREAD_POSTS'	=> 'Neperskaityti pranešimai',
+	'UNWATCH_FORUM_CONFIRM'	=> 'Ar tikrai norite atsisakyti gauti perspėjimus apie naujus pranešimus šiame forume?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Ar tikrai norite atsisakyti gauti perspėjimus apie naujus pranešimus forume “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'	=> 'Ar tikrai norite atsisakyti gauti perspėjimus apie naujus pranešimus šioje temoje?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Ar tikrai norite atsisakyti gauti perspėjimus apie naujus pranešimus temoje “%s”?',
 	'UNWATCHED_FORUMS'	=> 'Jūs atsisakėte gauti perspėjimus apie naujus pranešimus pasirinktuose forumuose.',
 	'UNWATCHED_TOPICS'	=> 'Jūs atsisakėte gauti perspėjimus apie naujus pranešimus pasirinktose temose.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Jūs atsisakėte gauti perspėjimus apie naujus pranešimus pasirinktose temose ir forumuose.',
@@ -663,6 +669,10 @@ $lang = array_merge($lang, array(
 	'VISIT_WEBSITE'	=> 'Apsilankyti puslapyje',
 	'WARNINGS'	=> 'Perspėjimai',
 	'WARN_USER'	=> 'Perspėti vartotoją',
+	'WATCH_FORUM_CONFIRM'	=> 'Ar tikrai norite užsisakyti gauti perspėjimus apie naujus pranešimus šiame forume?',
+	'WATCH_FORUM_DETAILED'	=> 'Ar tikrai norite užsisakyti gauti perspėjimus apie naujus pranešimus forume “%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Ar tikrai norite užsisakyti gauti perspėjimus apie naujus pranešimus šioje temoje?',
+	'WATCH_TOPIC_DETAILED'	=> 'Ar tikrai norite užsisakyti gauti perspėjimus apie naujus pranešimus temoje “%s”?',
 	'WELCOME_SUBJECT'	=> 'Sveiki atvykę į %s diskusijas',
 	'WEBSITE'	=> 'Puslapis',
 	'WHOIS'	=> 'Informacija apie IP adresą',
