@@ -5,8 +5,8 @@
 *
 * @package language
 * @version $Id: $
-* @copyright (c) 2011 phpBB Group
-* @author 2011-07-15 - Vilius Šumskas
+* @copyright (c) 2012 phpBB Group
+* @author 2012-01-04 - Vilius Šumskas
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -130,6 +130,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'	=> 'Dabartinis paveikslėlis',
 	'CURRENT_PASSWORD'	=> 'Dabartinis slaptažodis',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'Jeigu norite pakeisti savo slaptažodį, vartotojo vardą, arba el. pašto adresą, turite įrašyti dabartinį slaptažodį.',
+	'CUR_PASSWORD_EMPTY'	=> 'Jūs neįrašėte dabartinio slaptažodžio.',
 	'CUR_PASSWORD_ERROR'	=> 'Slaptažodis, kurį įrašėte, yra neteisingas.',
 	'CUSTOM_DATEFORMAT'	=> 'Individualus…',
 	'DEFAULT_ACTION'	=> 'Standartinis veiksmas',
@@ -249,9 +250,11 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'	=> 'Keliant žinutes į naują katalogą įvyko klaida. Perkeltos tik %1d iš %2d žinučių.',
 	'MOVE_TO_FOLDER'	=> 'Perkelti į katalogą',
 	'MOVE_UP'	=> 'Perkelti aukštyn',
+	'NEW_EMAIL_CONFIRM_EMPTY'	=> 'Jūs neįrašėte el. pašto adreso patvirtinimui.',
 	'NEW_EMAIL_ERROR'	=> 'El. pašto adresai, kuriuos įrašėte, nesutampa.',
 	'NEW_FOLDER_NAME'	=> 'Naujo katalogo pavadinimas',
 	'NEW_PASSWORD'	=> 'Naujas slaptažodis',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'Jūs neįrašėte slaptažodžio patvirtinimui.',
 	'NEW_PASSWORD_ERROR'	=> 'Slaptažodžiai, kuriuos įrašėte, nesutampa.',
 	'NOTIFY_METHOD'	=> 'Informavimo būdas',
 	'NOTIFY_METHOD_BOTH'	=> 'Abu',
